@@ -1,12 +1,12 @@
 # -*- coding: utf-8 -*-
 import array
 import operator
+import re
 from base64 import b64decode
-from reportlab.pdfgen.canvas import FILL_EVEN_ODD
-import sys
 
 import qrcode
 from reportlab.lib.units import toLength
+from reportlab.pdfgen.canvas import FILL_EVEN_ODD
 
 
 DEFAULT_PARAMS = {
@@ -63,6 +63,7 @@ class ReportlabImageBase(qrcode.image.base.BaseImage):
 		'x': Transforms.to_length,
 		'y': Transforms.to_length,
 		'invert': Transforms.to_bool,
+		'negative': Transforms.to_bool,
 		'mask': Transforms.to_bool,
 		'radius': Transforms.to_float,
 		'enhanced_path': Transforms.to_bool,
@@ -72,10 +73,13 @@ class ReportlabImageBase(qrcode.image.base.BaseImage):
 	padding = '2.5'
 	bg = None
 	fg = '#000000'
+	bg_alpha = 1.0
+	fg_alpha = 1.0
 	bitmap = None
 	x = 0
 	y = 0
 	invert = False
+	negative = False
 	mask = False
 	enhanced_path = None
 	radius = 0
@@ -93,6 +97,8 @@ class ReportlabImageBase(qrcode.image.base.BaseImage):
 				self.padding = toLength(self.padding) if isinstance(self.padding, str) else float(self.padding)
 		if self.enhanced_path is None:
 			self.enhanced_path = self.radius == 0
+		self.parse_color('fg')
+		self.parse_color('bg')
 
 	def drawrect(self, row, col):
 		self.bitmap_set((col, row), 0 if self.invert else 1)
@@ -128,12 +134,20 @@ class ReportlabImageBase(qrcode.image.base.BaseImage):
 				self.draw_background(stream)
 				# Set foreground
 				stream.setFillColor(self.fg)
+				stream.setFillAlpha(self.fg_alpha)
 
 			# Set transform matrix
 			scale = (self.size - (self.padding * 2.0)) / self.width
 			transform(scale, 0.0, 0.0, scale, self.padding, self.padding)
 
 			p = stream.beginPath()
+			if self.negative:
+				pad = self.padding / scale
+				p.moveTo(-pad, -pad)
+				p.lineTo(self.width + pad, -pad)
+				p.lineTo(self.width + pad, self.width + pad)
+				p.lineTo(-pad, self.width + pad)
+				p.close()
 			if self.radius == 0:
 				p = self.draw_code(p)
 			else:
@@ -145,6 +159,7 @@ class ReportlabImageBase(qrcode.image.base.BaseImage):
 		finally:
 			if self.mask:
 				restore_transform()
+				stream.setFillAlpha(1.0)
 			else:
 				stream.restoreState()
 
@@ -154,6 +169,7 @@ class ReportlabImageBase(qrcode.image.base.BaseImage):
 		"""
 		if self.bg is not None:
 			stream.setFillColor(self.bg)
+			stream.setFillAlpha(self.bg_alpha)
 			stream.rect(0, 0, self.size, self.size, fill=1, stroke=0)
 
 	def draw_code(self, p):
@@ -239,6 +255,18 @@ class ReportlabImageBase(qrcode.image.base.BaseImage):
 			segment = self.__consume_segment()
 		return segments
 
+	def parse_color(self, color_name):
+		color = getattr(self, color_name)
+		if color is None:
+			return
+		alpha = 1.0
+		if re.match(r'^#[0-9a-f]{8}$', color.lower()):
+			color = color.lower()
+			alpha = int(color[-2:], base=16) / 255
+			color = color[:7]
+		setattr(self, color_name, color)
+		setattr(self, f'{color_name}_alpha', alpha)
+
 	def __consume_segment(self):
 		"""
 		Returns segment of qr image as path (pairs of x, y coordinates)
