@@ -114,6 +114,19 @@ def test_mask():
 	assert img.mask == True
 
 
+def test_negative():
+	qr(get_canvas(), 'negative=1;text;Negative')
+	img = build_qrcode(*parse_params_string('negative=1;text;Negative'))
+	assert img.negative == True
+
+
+def test_alpha():
+	qr(get_canvas(), 'negative=1;text;Negative')
+	img = build_qrcode(*parse_params_string('fg=#ffffffcc,bg=#ffffff80;text;Negative'))
+	assert img.fg_alpha == pytest.approx(0.8, 0.01)
+	assert img.bg_alpha == pytest.approx(0.5, 0.01)
+
+
 def test_custom_error_correction():
 	c = get_canvas()
 	qr(c, 'error_correction=M;text;Error correction')
